@@ -66,12 +66,12 @@ static pthread_mutex_t builtin_mutex = PTHREAD_MUTEX_INITIALIZER;
 // MSVC lacks the POSIX macro S_ISDIR, however it's a trivial one:
 #ifndef S_ISDIR
 #define S_ISDIR(m) (((m) & _S_IFMT) == _S_IFDIR)
-#ifndef HAVE_SNPRINTF
-#include "vsnprintf.h"
 #endif
 #endif
 
-#define strcasecmp      stricmp
+#if defined(_MSC_VER)
+#define snprintf _snprintf
+#define strcasecmp stricmp
 #endif
 
 /** This is the toplevel directory where the timezone data is installed in. */
@@ -426,7 +426,7 @@ icaltimezone_get_tznames_from_vtimezone (icalcomponent *component)
     /* If both standard and daylight TZNAMEs were found, if they are the same
        we return just one, else we format them like "EST/EDT". */
     if (standard_tzname && daylight_tzname) {
-	unsigned int standard_len, daylight_len;
+	size_t standard_len, daylight_len;
 	char *tznames;
 
 	if (!strcmp (standard_tzname, daylight_tzname))
@@ -571,6 +571,14 @@ icaltimezone_expand_vtimezone		(icalcomponent	*comp,
 	prop = icalcomponent_get_next_property (comp, ICAL_ANY_PROPERTY);
     }
 
+    /* Microsoft Outlook for Mac (and possibly other versions) will create
+       timezones without a tzoffsetfrom property if it's a timezone that
+       doesn't change for DST. */
+    if (found_tzoffsetto && !found_tzoffsetfrom) {
+        change.prev_utc_offset = change.utc_offset;
+        found_tzoffsetfrom = 1;
+    }
+
     /* If we didn't find a DTSTART, TZOFFSETTO and TZOFFSETFROM we have to
        ignore the component. FIXME: Add an error property? */
     if (!found_dtstart || !found_tzoffsetto || !found_tzoffsetfrom)
@@ -1337,7 +1345,7 @@ icaltimezone_get_builtin_timezone	(const char *location)
 {
     icalcomponent *comp;
     icaltimezone *zone;
-    int lower;
+    unsigned int lower;
     const char *zone_location;
 
     if (!location || !location[0])
@@ -1477,18 +1485,17 @@ icaltimezone_get_builtin_timezone_from_tzid (const char *tzid)
     if (strncmp (tzid, ical_tzid_prefix, strlen(ical_tzid_prefix)))
 	return NULL;
 
-    /* Get the location, which is after the 4th '/' character. */
-    /* format is /unique_prefix/Olson_X/Tzfile/location */
+    /* Get the location, which is after the 3rd '/' character. */
     p = tzid;
     for (p = tzid; *p; p++) {
 	if (*p == '/') {
 	    num_slashes++;
-	    if (num_slashes == 4)
+	    if (num_slashes == 3)
 		break;
 	}
     }
 
-    if (num_slashes != 4)
+    if (num_slashes != 3)
 	return NULL;
 
     p++;
@@ -1566,7 +1573,7 @@ parse_coord			(char		*coord,
 }
 static int
 fetch_lat_long_from_string  (const char *str, int *latitude_degrees, int *latitude_minutes, int *latitude_seconds,
-		int *longitude_degrees, int *longitude_minutes, int *longitude_seconds, char *location)
+			     int *longitude_degrees, int *longitude_minutes, int *longitude_seconds, char *location)
 {
 	size_t len;
 	char *sptr, *lat, *lon, *loc, *temp;
@@ -1610,12 +1617,17 @@ fetch_lat_long_from_string  (const char *str, int *latitude_degrees, int *latitu
 	while (*lon != '+' && *lon != '-')
 		lon++;
 
-	if (parse_coord (lat, lon - lat, latitude_degrees, latitude_minutes, latitude_seconds) == 1 ||
-		       	parse_coord (lon, strlen (lon), longitude_degrees, longitude_minutes, longitude_seconds) 
-			== 1) {
-				free(lat);
-				return 1;
-			}
+	if (parse_coord (lat, (int)(lon - lat),
+			 latitude_degrees,
+			 latitude_minutes,
+			 latitude_seconds) == 1 ||
+	    parse_coord (lon, (int)strlen(lon),
+			 longitude_degrees,
+			 longitude_minutes,
+			 longitude_seconds) == 1) {
+	    free(lat);
+	    return 1;
+	}
 	
 	free (lat);
 
@@ -1636,7 +1648,7 @@ icaltimezone_parse_zone_tab		(void)
     FILE *fp;
     char buf[1024];  /* Used to store each line of zones.tab as it is read. */
     char location[1024]; /* Stores the city name when parsing buf. */
-    unsigned int filename_len;
+    size_t filename_len;
     int latitude_degrees = 0, latitude_minutes = 0, latitude_seconds = 0;
     int longitude_degrees = 0, longitude_minutes = 0, longitude_seconds = 0;
     icaltimezone zone;
@@ -1733,7 +1745,7 @@ icaltimezone_parse_zone_tab		(void)
 void
 icaltimezone_release_zone_tab		(void)
 {
-    int i;
+    unsigned int i;
     icalarray *mybuiltin_timezones = builtin_timezones;
 
     if (builtin_timezones == NULL)
