@@ -3,7 +3,7 @@
   FILE: sspm.c Parse Mime
   CREATOR: eric 25 June 2000
   
-  $Id: sspm.c 463628 2005-09-24 16:27:03Z winterz $
+  $Id: sspm.c,v 1.13 2008-01-28 22:34:38 artcancro Exp $
   $Locker:  $
     
  The contents of this file are subject to the Mozilla Public License
@@ -30,7 +30,8 @@
 
   The Initial Developer of the Original Code is Eric Busboom
 
- (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
  ======================================================================*/
 
 #include <stdio.h>
@@ -45,9 +46,9 @@
 #include "dmalloc.h"
 #endif
 
-#ifdef WIN32
-#define snprintf      _snprintf
-#define strcasecmp    stricmp
+#if defined(_MSC_VER)
+#define snprintf _snprintf
+#define strcasecmp stricmp
 #endif
 
 #define TMP_BUF_SIZE 1024
@@ -69,7 +70,7 @@ struct mime_impl{
 	size_t max_parts;
 	int part_no;
 	int level;
-	struct sspm_action_map *actions;
+	const struct sspm_action_map *actions;
 	char* (*get_string)(char *s, size_t size, void* data);
 	void* get_string_data;
 	char temp[TMP_BUF_SIZE];
@@ -80,7 +81,7 @@ void sspm_free_header(struct sspm_header *header);
 void* sspm_make_multipart_part(struct mime_impl *impl,struct sspm_header *header);
 void sspm_read_header(struct mime_impl *impl,struct sspm_header *header);
 
-char* sspm_strdup(char* str){
+char* sspm_strdup(const char* str){
 
     char* s;
 
@@ -92,10 +93,10 @@ char* sspm_strdup(char* str){
 
 static struct  major_content_type_map 
 {
-	enum sspm_major_type type;
-	char* str;
-	
-} major_content_type_map[]  = 
+    enum sspm_major_type type;
+    const char* str;
+
+} major_content_type_map[]  =
 {
     {SSPM_MULTIPART_MAJOR_TYPE,"multipart" },
     {SSPM_TEXT_MAJOR_TYPE,"text" },
@@ -111,8 +112,8 @@ static struct  major_content_type_map
 
 static struct  minor_content_type_map 
 {
-	enum sspm_minor_type type;
-	char* str;
+    enum sspm_minor_type type;
+    const char* str;
 
 } minor_content_type_map[]  = 
 {
@@ -131,8 +132,8 @@ static struct  minor_content_type_map
 
 
 struct encoding_map {
-	enum sspm_encoding encoding;
-	char* str;
+    enum sspm_encoding encoding;
+    const char* str;
 } sspm_encoding_map[] = 
 {
     {SSPM_NO_ENCODING,""},
@@ -146,7 +147,7 @@ struct encoding_map {
 };
 
 
-char* sspm_get_parameter(char* line, char* parameter)
+char* sspm_get_parameter(const char* line, const char* parameter)
 {
     char *p,*s,*q;
     static char name[1024];
@@ -180,7 +181,8 @@ char* sspm_get_parameter(char* line, char* parameter)
     if(s != 0){
 	strncpy(name,p,(size_t)s-(size_t)p);
     } else {
-	strcpy(name,p);
+	strncpy(name,p,sizeof(name)-1);
+	name[sizeof(name)-1]='\0';
     }
 
     /* Strip off trailing quote, if it exists */
@@ -194,7 +196,7 @@ char* sspm_get_parameter(char* line, char* parameter)
     return name;
 }
 
-char* sspm_property_name(char* line)
+char* sspm_property_name(const char* line)
 {
     static char name[1024];
     char *c = strchr(line,':');
@@ -216,7 +218,10 @@ char* sspm_value(char* line)
 
     /* Find the first colon and the next semicolon */
 
+    value[0] = 0;
     c = strchr(line,':');
+    if (!c)
+      return value;
     s = strchr(c,';');
 
     /* Skip the colon */
@@ -238,7 +243,7 @@ char* sspm_value(char* line)
 
 }
 
-static char *mime_headers[] = {
+static const char *mime_headers[] = {
     "Content-Type",
     "Content-Transfer-Encoding",
     "Content-Disposition",
@@ -248,22 +253,28 @@ static char *mime_headers[] = {
 };
 
 
-void* sspm_default_new_part()
+void* sspm_default_new_part(void)
 {
     return 0;
 }
 void sspm_default_add_line(void *part, struct sspm_header *header, 
-			   char* line, size_t size)
+			   const char* line, size_t size)
 {
+    (void)part;
+    (void)header;
+    (void)line;
+    (void)size;
 }
 
 void* sspm_default_end_part(void* part)
 {
+    (void)part;
     return 0;
 }
 
 void sspm_default_free_part(void *part)
 {
+    (void)part;
 }
 
 
@@ -424,12 +435,12 @@ static struct sspm_action_map get_action(struct mime_impl *impl,
 char* sspm_lowercase(char* str)
 {
     char* p = 0;
-    char* new = sspm_strdup(str);
+    char* new;
 
     if(str ==0){
 	return 0;
     }
-
+    new = sspm_strdup(str);
     for(p = new; *p!=0; p++){
 	*p = tolower(*p);
     }
@@ -443,7 +454,7 @@ enum sspm_major_type sspm_find_major_content_type(char* type)
 
     char* ltype = sspm_lowercase(type);
 
-    for (i=0; major_content_type_map[i].type !=  SSPM_UNKNOWN_MINOR_TYPE; i++){
+    for (i=0; major_content_type_map[i].type !=  SSPM_UNKNOWN_MAJOR_TYPE; i++){
 	if(strncmp(ltype, major_content_type_map[i].str,
 		   strlen(major_content_type_map[i].str))==0){
 	    free(ltype);
@@ -462,6 +473,7 @@ enum sspm_minor_type sspm_find_minor_content_type(char* type)
     char *p = strchr(ltype,'/');
 
     if (p==0){
+        free(ltype);
 	return SSPM_UNKNOWN_MINOR_TYPE; 
     }
 
@@ -479,7 +491,7 @@ enum sspm_minor_type sspm_find_minor_content_type(char* type)
     return minor_content_type_map[i].type; /* Should return SSPM_UNKNOWN_MINOR_TYPE */
 }
 
-char* sspm_major_type_string(enum sspm_major_type type)
+const char* sspm_major_type_string(enum sspm_major_type type)
 {
     int i;
 
@@ -494,7 +506,7 @@ char* sspm_major_type_string(enum sspm_major_type type)
     return major_content_type_map[i].str; /* Should return SSPM_UNKNOWN_MINOR_TYPE */
 }
 
-char* sspm_minor_type_string(enum sspm_minor_type type)
+const char* sspm_minor_type_string(enum sspm_minor_type type)
 {
     int i;
     for (i=0; minor_content_type_map[i].type !=  SSPM_UNKNOWN_MINOR_TYPE; 
@@ -508,7 +520,7 @@ char* sspm_minor_type_string(enum sspm_minor_type type)
 }
 
 
-char* sspm_encoding_string(enum sspm_encoding type)
+const char* sspm_encoding_string(enum sspm_encoding type)
 {
     int i;
     for (i=0; sspm_encoding_map[i].encoding !=  SSPM_UNKNOWN_ENCODING; 
@@ -920,7 +932,7 @@ void sspm_read_header(struct mime_impl *impl,struct sspm_header *header)
 #define MAX_HEADER_LINES 25
 
     char *buf;
-    char header_lines[MAX_HEADER_LINES][BUF_SIZE]; /* HACK, hard limits */
+    char header_lines[MAX_HEADER_LINES][BUF_SIZE]; /* HACK, hard limits TODO*/
     int current_line = -1;
     int end = 0;
 
@@ -935,7 +947,9 @@ void sspm_read_header(struct mime_impl *impl,struct sspm_header *header)
     header->error_text = 0;
 
     /* Read all of the lines into memory */
-    while(end==0&& (buf=sspm_get_next_line(impl)) != 0){
+    while(current_line<(MAX_HEADER_LINES-2) && 
+	  (end==0) && 
+	  ((buf=sspm_get_next_line(impl)) != 0)){
 
 	enum line_type line_type = get_line_type(buf);
 	
@@ -1015,7 +1029,7 @@ void sspm_read_header(struct mime_impl *impl,struct sspm_header *header)
 /* Root routine for parsing mime entries*/
 int sspm_parse_mime(struct sspm_part *parts, 
 		    size_t max_parts,
-		    struct sspm_action_map *actions,
+		    const struct sspm_action_map *actions,
 		    char* (*get_string)(char *s, size_t size, void* data),
 		    void *get_string_data,
 		    struct sspm_header *first_header
@@ -1025,6 +1039,7 @@ int sspm_parse_mime(struct sspm_part *parts,
     struct sspm_header header;
     void *part;
     int i;
+    (void)first_header;
 
     /* Initialize all of the data */
     memset(&impl,0,sizeof(struct mime_impl));
@@ -1169,7 +1184,7 @@ char *decode_base64(char *dest,
 			     char *src,
 			     size_t *size)
 {
-    int cc;
+    int cc = 0;
     char buf[4] = {0,0,0,0};  
     int p = 0;
     int valid_data = 0;
@@ -1243,7 +1258,7 @@ struct sspm_buffer {
 	int line_pos;
 };
 
-void sspm_append_string(struct sspm_buffer* buf, char* string);
+void sspm_append_string(struct sspm_buffer* buf, const char* string);
 void sspm_write_part(struct sspm_buffer *buf,struct sspm_part *part, int *part_num);
 
 void sspm_append_hex(struct sspm_buffer* buf, char ch)
@@ -1284,7 +1299,7 @@ void sspm_append_char(struct sspm_buffer* buf, char ch)
     *(buf->pos) = 0;
 }
 /* A copy of icalmemory_append_string */
-void sspm_append_string(struct sspm_buffer* buf, char* string)
+void sspm_append_string(struct sspm_buffer* buf, const char* string)
 {
     char *new_buf;
     char *new_pos;
@@ -1414,12 +1429,12 @@ void sspm_write_base64(struct sspm_buffer *buf, char* inbuf,int size )
              
 void sspm_encode_base64(struct sspm_buffer *buf, char* data, size_t size)
 {
-
     char *p;
     char inbuf[3];
     int i = 0;
     int first = 1;
     int lpos = 0;
+    (void)size;
 
     inbuf[0] = inbuf[1] = inbuf[2]  = 0;
 
@@ -1466,8 +1481,8 @@ void sspm_write_header(struct sspm_buffer *buf,struct sspm_header *header)
     
     int i;
     char temp[TMP_BUF_SIZE];			       
-    char* major; 
-    char* minor; 
+    const char* major; 
+    const char* minor; 
     
     /* Content-type */
 
@@ -1491,9 +1506,9 @@ void sspm_write_header(struct sspm_buffer *buf,struct sspm_header *header)
     /* Append any content type parameters */    
     if(header->content_type_params != 0){
 	for(i=0; *(header->content_type_params[i])!= 0;i++){
-	    snprintf(temp,sizeof(temp),header->content_type_params[i]);
-	    sspm_append_char(buf,';');
-	    sspm_append_string(buf,temp);
+		snprintf(temp, sizeof(temp),"%s", header->content_type_params[i]);
+		sspm_append_char(buf, ';');
+		sspm_append_string(buf, temp);
 	}
     }
     
@@ -1553,6 +1568,7 @@ void sspm_write_multipart_part(struct sspm_buffer *buf,
 
 void sspm_write_part(struct sspm_buffer *buf,struct sspm_part *part,int *part_num)
 {
+    (void)part_num;
 
     /* Write header */
     sspm_write_header(buf,&(part->header));
@@ -1576,12 +1592,15 @@ void sspm_write_part(struct sspm_buffer *buf,struct sspm_part *part,int *part_nu
 }
 
 int sspm_write_mime(struct sspm_part *parts,size_t num_parts,
-		    char **output_string, char* header)
+		    char **output_string, const char* header)
 {
     struct sspm_buffer buf;
     int part_num =0;
+    size_t slen;
+    (void)num_parts;
 
     buf.buffer = malloc(4096);
+    buf.buffer[0] = '\0';
     buf.pos = buf.buffer;
     buf.buf_size = 10;
     buf.line_pos = 0;
@@ -1591,7 +1610,8 @@ int sspm_write_mime(struct sspm_part *parts,size_t num_parts,
 	sspm_append_string(&buf,header);
     }
 
-    if(buf.buffer[strlen(buf.buffer)-1] != '\n'){
+    slen = strlen(buf.buffer);
+    if(slen > 0 && buf.buffer[slen-1] != '\n'){
 	sspm_append_char(&buf,'\n');
     }
 
